---
name: "\U0001F41B Bug Report"
about: Report a reproducible bug
title: ''
labels: ''
assignees: ''

---

**Read the Contribution Guidelines**
Before creating a bug report on this issue tracker, you **must** read the [Contribution Guidelines](https://github.com/markqvist/Reticulum/blob/master/Contributing.md). Issues that do not follow the contribution guidelines **will be deleted without comment**.

- The issue tracker is used by developers of this project. **Do not use it to ask general questions, or for support requests**.
- Ideas and feature requests can be made on the [Discussions](https://github.com/markqvist/Reticulum/discussions). **Only** feature requests accepted by maintainers and developers are tracked and included on the issue tracker. **Do not post feature requests here**.
- After reading the [Contribution Guidelines](https://github.com/markqvist/Reticulum/blob/master/Contributing.md), delete this section from your bug report.

**Describe the Bug**
A clear and concise description of what the bug is.

**To Reproduce**
Describe in detail how to reproduce the bug.

**Expected Behavior**
A clear and concise description of what you expected to happen.

**Logs & Screenshots**
Please include any relevant log output. If applicable, also add screenshots to help explain your problem.

**System Information**
- OS and version
- Python version
- Program version

**Additional context**
Add any other context about the problem here.
